==> cxf-systests-jaxrs-4.1.1-sources.jar: org/apache/cxf/systest/jaxrs/codegen/schema/Book.java <==

package org.apache.cxf.systest.jaxrs.codegen.schema;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for book complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="book">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://superbooks}thechapter" minOccurs="0"/>
 *         <element name="id" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "book", propOrder = {
    "thechapter",
    "id"
})
public class Book {

    @XmlElement(namespace = "http://superbooks")
    protected Chapter thechapter;
    protected int id;

    /**
     * Gets the value of the thechapter property.
     * 
     * @return
     *     possible object is
     *     {@link Chapter }
     *     
     */
    public Chapter getThechapter() {
        return thechapter;
    }

    /**
     * Sets the value of the thechapter property.
     * 
     * @param value
     *     allowed object is
     *     {@link Chapter }
     *     
     */
    public void setThechapter(Chapter value) {
        this.thechapter = value;
    }

    /**
     * Gets the value of the id property.
     * 
     */
    public int getId() {
        return id;
    }

    /**
     * Sets the value of the id property.
     * 
     */
    public void setId(int value) {
        this.id = value;
    }

}

==> cxf-systests-jaxrs-4.1.4-sources.jar: org/apache/cxf/systest/jaxrs/codegen/schema/Book.java <==

package org.apache.cxf.systest.jaxrs.codegen.schema;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * &lt;p&gt;Java class for book complex type&lt;/p&gt;.
 * 
 * &lt;p&gt;The following schema fragment specifies the expected content contained within this class.&lt;/p&gt;
 * 
 * &lt;pre&gt;{&#064;code
 * &lt;complexType name="book"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{http://superbooks}thechapter" minOccurs="0"/&gt;
 *         &lt;element name="id" type="{http://www.w3.org/2001/XMLSchema}int"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * }&lt;/pre&gt;
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "book", propOrder = {
    "thechapter",
    "id"
})
public class Book {

    @XmlElement(namespace = "http://superbooks")
    protected Chapter thechapter;
    protected int id;

    /**
     * Gets the value of the thechapter property.
     * 
     * @return
     *     possible object is
     *     {@link Chapter }
     *     
     */
    public Chapter getThechapter() {
        return thechapter;
    }

    /**
     * Sets the value of the thechapter property.
     * 
     * @param value
     *     allowed object is
     *     {@link Chapter }
     *     
     */
    public void setThechapter(Chapter value) {
        this.thechapter = value;
    }

    /**
     * Gets the value of the id property.
     * 
     */
    public int getId() {
        return id;
    }

    /**
     * Sets the value of the id property.
     * 
     */
    public void setId(int value) {
        this.id = value;
    }

}
